@@ -5,6 +5,6 @@
 # @File    : __init__.py.py
 # @Desc    :
 
-from web_extractor.ce_test import (
+from web_extractor.test import (
     cs_test
 )
\ No newline at end of file
